@@ -37,7 +37,6 @@ int main(int, char**)
   g_type_init ();
 
   std::cout << get_defs(G_TYPE_ASYNC_RESULT)
-            << get_defs(G_TYPE_APPLICATION)
             << get_defs(G_TYPE_CANCELLABLE)
             << get_defs(G_TYPE_BUFFERED_INPUT_STREAM)
             << get_defs(G_TYPE_BUFFERED_OUTPUT_STREAM)
@@ -70,6 +69,10 @@ int main(int, char**)
             << get_defs(G_TYPE_MEMORY_OUTPUT_STREAM)
             << get_defs(G_TYPE_MOUNT)
             << get_defs(G_TYPE_MOUNT_OPERATION)
+            << get_defs(G_TYPE_PROXY)
+            << get_defs(G_TYPE_PROXY_ADDRESS)
+            << get_defs(G_TYPE_PROXY_ADDRESS_ENUMERATOR)
+            << get_defs(G_TYPE_PROXY_RESOLVER)
             << get_defs(G_TYPE_SEEKABLE)
             << get_defs(G_TYPE_SETTINGS)
             << get_defs(G_TYPE_SETTINGS_BACKEND)
